# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 21:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0012_auto_20170311_2124'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visadevice',
            name='alias',
            field=models.CharField(default='1a357258-ae90-48ff-af86-c97934780e93', max_length=200),
        ),
    ]
