# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 21:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0010_auto_20170311_2115'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visadevice',
            name='alias',
            field=models.CharField(default='66bcf3f8-7f53-47c6-8eb0-3efb9283390e', max_length=200),
        ),
    ]
