# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 16:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0005_auto_20170311_1658'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visadevice',
            name='alias',
            field=models.CharField(default='0f5842de-6d7d-4c12-b25a-85eebed30e45', max_length=200),
        ),
    ]
