# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 21:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0008_auto_20170311_1724'),
    ]

    operations = [
        migrations.AlterField(
            model_name='visadevice',
            name='alias',
            field=models.CharField(default='248eda5b-68f5-4b0c-ace2-fd9d23bada4e', max_length=200),
        ),
    ]
