# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 15:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='StationControllerSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data_collector', models.CharField(max_length=200)),
                ('start_date', models.DateTimeField()),
                ('end_date', models.DateTimeField()),
            ],
        ),
        migrations.CreateModel(
            name='VisaEvent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('alias', models.CharField(max_length=200)),
                ('address', models.CharField(max_length=200)),
                ('command', models.CharField(max_length=200)),
                ('execution_date', models.DateTimeField(verbose_name='date published')),
                ('session', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='visaweb.StationControllerSession')),
            ],
        ),
    ]
