# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 16:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0002_auto_20170311_1614'),
    ]

    operations = [
        migrations.AddField(
            model_name='visaevent',
            name='operation',
            field=models.CharField(default='query', max_length=200),
        ),
        migrations.AddField(
            model_name='visaevent',
            name='success',
            field=models.BooleanField(default=True),
        ),
    ]
