# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-11 16:14
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='VisaSession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('alias', models.CharField(max_length=200)),
                ('address', models.CharField(max_length=200)),
            ],
        ),
        migrations.RenameField(
            model_name='visaevent',
            old_name='address',
            new_name='request',
        ),
        migrations.RenameField(
            model_name='visaevent',
            old_name='alias',
            new_name='response',
        ),
        migrations.RemoveField(
            model_name='visaevent',
            name='command',
        ),
        migrations.AlterField(
            model_name='visaevent',
            name='session',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='visaweb.VisaSession'),
        ),
        migrations.DeleteModel(
            name='StationControllerSession',
        ),
    ]
